@@ -16,9 +16,9 @@ def getpackagepath(packagepath, first=True):
             if(result != ""): return result
     return ""
 def getscriptpath(packagepath):
-    if os.path.isfile( os.path.join(packagepath, "agent.py")): return os.path.join(packagepath, "agent.py")
-    if os.path.isfile( os.path.join(packagepath, "main.py")): return os.path.join(packagepath, "main.py")
-    if os.path.isfile( os.path.join(packagepath, "index.py")): return os.path.join(packagepath, "index.py")
+    if os.path.isfile( os.path.join(packagepath, "agent.py")): return "agent.py"
+    if os.path.isfile( os.path.join(packagepath, "main.py")): return "main.py"
+    if os.path.isfile( os.path.join(packagepath, "index.py")): return "index.py"
     return ""
 def gitclone(url):
     directory = "package"
@@ -28,7 +28,8 @@ def gitclone(url):
 def pipinstall(packagepath):
     if os.path.isfile( os.path.join(packagepath, "requirements.txt")):
         subprocess.check_call([sys.executable, "-m", "pip", "install", "-r", os.path.join(packagepath, "requirements.txt")])
-def runit(command):
+def runit(packagepath,command):
+    os.chdir(packagepath)
     return subprocess.check_output([sys.executable, command])
 def gunzip_shutil(source_filepath, dest_filepath, block_size=65536):
     with gzip.open(source_filepath, 'rb') as s_file, \
@@ -66,4 +67,4 @@ if __name__ == '__main__':
     if command == "":
         sys.exit(f"Failed locating a command to run, EXIT!")
     pipinstall(packagepath)
-    print(runit(command).decode('utf-8'))
+    print(runit(packagepath, command).decode('utf-8'))
