@@ -59,10 +59,9 @@ class Client():
         self.messagequeues = {}
         self.queue = Queue()
         threading.Thread(target=self.__listen_for_messages, daemon=True).start()
+        threading.Thread(target=self.__server_pinger, daemon=True).start()
         # self.send_queue = queue.SimpleQueue() # or Queue if using Python before 3.7
         # threading.Thread(target=self.__server_pinger, args=(queue,)).start()
-        # threading.Thread(target=self.__listen_for_messages, args=(queue,)).start()
-        # threading.Thread(target=self.__server_pinger, daemon=True).start()
 
         # uri = urlparse(self.url)
         # if(uri.username != None and uri.username != "" and uri.password != None and uri.password != ""):
@@ -117,6 +116,10 @@ class Client():
             msg = base_pb2.pong()
             msg.ParseFromString(message.data.value);
             return msg
+        elif(message.command == "ping"):
+            msg = base_pb2.ping()
+            msg.ParseFromString(message.data.value);
+            return msg
         elif(message.command == "error"):
             msg = base_pb2.error()
             msg.ParseFromString(message.data.value);
@@ -147,11 +150,12 @@ class Client():
     def __connect_and_listen(self, itr):
         try:
             uri = urlparse(self.url)
-            logging.info(f"Connecting to {uri.hostname}:")
             if(uri.port == 443 or uri.port == "443"):
+                logging.info(f"Connecting to {uri.hostname}:{uri.port} using ssl credentials")
                 credentials = grpc.ssl_channel_credentials()
                 self.chan = grpc.secure_channel(f"{uri.hostname}:{uri.port}", credentials, options=(('grpc.ssl_target_name_override', uri.hostname),))
             else:
+                logging.info(f"Connecting to {uri.hostname}:{uri.port}")
                 self.chan = grpc.insecure_channel(f"{uri.hostname}:{uri.port}")
             fut = grpc.channel_ready_future(self.chan)
             while not fut.done():
@@ -212,6 +216,8 @@ class Client():
                 # print(f"recevied {message.command}")
                 asyncio.run_coroutine_threadsafe(self.messagequeues[msg.queuename](self, msg), self.loop)
                 # print(f"processed {message.command}")
+            if(message.command == "ping" or message.command == "pong"):
+                time.sleep(1)
             else:
                 # self.trigger("message", message.command, message.id, msg)
                 # reply = asyncio.run(self.onmessage(self, message.command, message.id, msg))
@@ -225,9 +231,10 @@ class Client():
         count = 0
         while True:
             time.sleep(5)
-            asyncio.run(self.__ping())
-            # message = envelope(command="ping")
-            # self.queue.put(message)
+            if(self.connected):
+                message = envelope(command="ping")
+                self.queue.put(message)
+            time.sleep(25)
             count += 1
     def __request_iterator(self, connectonid):
         logging.debug(f"Waiting for message for connecton id {connectonid}")
@@ -263,8 +270,6 @@ class Client():
         self.queue.put(request)
         return future
     async def __ping(self):
-        # self.__Send(base_pb2.envelope(command="ping"), "")
-        # self.queue.put(base_pb2.envelope(command="ping"))
         await self.__RPC(base_pb2.envelope(command="ping"))
     def Send(self, request, rid):
         if(rid == None or rid == ""): raise ValueError("RID is mandatory")
@@ -277,7 +282,7 @@ class Client():
         signin = asyncio.run(self.Signin(username, password))
         logging.info(f"Signed in as {signin.name}" )
         self.__login_event.set()
-    async def Signin(self, username=None, password=None):
+    async def Signin(self, username=None, password=None, ping=True):
         request = base_pb2.envelope(command="signin")
         if(username == None and password==None):
             jwt = os.environ.get("jwt", "")
@@ -289,9 +294,9 @@ class Client():
                     username=uri.username
                     password=uri.password
         if(password== None or password == ""):
-            request.data.Pack(base_pb2.signin(jwt=username))
+            request.data.Pack(base_pb2.signin(jwt=username, ping=ping))
         else:
-            request.data.Pack(base_pb2.signin(username=username, password=password))
+            request.data.Pack(base_pb2.signin(username=username, password=password, ping=ping))
         result = await self.__RPC(request)
         self.jwt = result.jwt
         self.user = result.user
